from zs_utils.email.templates.oms import base

icon = "stock_icon.png"

title_ru = "У Вас низкий остаток по товару"
title_en = "You have a low stock for the product"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 40px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, количество товара опустилось ниже пользовательского значения.
            </td>
        </tr>
        </tbody>
    </table>
    <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 40px">
                <hr color="#EAE7FF">
            </td>
        </tr>
        <tr>
            <td style="font-size: 13px">
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%;">
                    <tbody>
                    <tr>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="20%">

                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="50%">
                            Товар
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="15%">
                            Sku
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="15%">
                            Кол-во
                        </td>
                    </tr>
                    <tr>
                        <td style="padding: 0 10px 10px">
                            <img src="{item_img_url}" alt="item_img_url" width="90px">
                        </td>
                        <td style="padding: 0 10px 10px">
                            <span style="color: #3BD0BC; font-weight: bold">{title}</span>
                        </td>
                        <td style="padding: 0 10px 10px">
                            <span style="color: #3BD0BC; font-weight: bold">{sku}</span>
                        </td>
                        <td style="padding: 0 10px 10px">
                            <span style="color: #3BD0BC; font-weight: bold">{quantity} шт</span>
                        </td>
                    </tr>
                    </tbody>
                </table>
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 50px 0 40px">
                <a href="{update_stocks_url}" class="button" style="color: #ffffff">
                    Редактировать остатки
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 40px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, the item's quantity has dropped below the custom value.
            </td>
        </tr>
        </tbody>
    </table>
    <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 40px">
                <hr color="#EAE7FF">
            </td>
        </tr>
        <tr>
            <td style="font-size: 13px">
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%;">
                    <tbody>
                    <tr>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="20%">

                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="50%">
                            Product
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="15%">
                            Sku
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="15%">
                            Quantity
                        </td>
                    </tr>
                    <tr>
                        <td style="padding: 0 10px 10px">
                            <img src="{item_img_url}" alt="item_img_url" width="90px">
                        </td>
                        <td style="padding: 0 10px 10px">
                            <span style="color: #3BD0BC; font-weight: bold">{title}</span>
                        </td>
                        <td style="padding: 0 10px 10px">
                            <span style="color: #3BD0BC; font-weight: bold">{sku}</span>
                        </td>
                        <td style="padding: 0 10px 10px">
                            <span style="color: #3BD0BC; font-weight: bold">{quantity} pcs</span>
                        </td>
                    </tr>
                    </tbody>
                </table>
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 50px 0 40px">
                <a href="{update_stocks_url}" class="button" style="color: #ffffff">
                    Edit stocks
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "best_offer_icon.png"

title_ru = "Новое предложение от покупателя на eBay"
title_en = "New eBay offer from buyer"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, добрый день!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                Вам поступило ценное предложение от потенциального покупателя <span style='color: #3BD0BC; font-weight: bold'>{buyer}</span> на eBay.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{best_offer_url}" class="button" style="color: #ffffff">
                    Рассмотреть предложение
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, good afternoon!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                You have received a valuable offer from a potential buyer <span style='color: #3BD0BC; font-weight: bold'>{buyer}</span> on eBay.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{best_offer_url}" class="button" style="color: #ffffff">
                    Consider the proposal
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "new_message_icon.png"

subject_ru = "Новое сообщение от покупателя на {marketplace_name}"
subject_en = "New message from {marketplace_name} buyer"

title_ru = "Новое сообщение от покупателя на {marketplace_name}"
title_en = "New message from {marketplace_name} buyer"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 30px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, вам поступило новое сообщение от потенциального покупателя <span style='color: #3BD0BC; font-weight: bold'>{sender}</span> на <b>{marketplace_name}</b>!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 20px">
                <hr color="#EAE7FF">
            </td>
        </tr>
        <tr>
            <td>
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%;">
                    <tbody>
                    <tr>
                        <td style="padding: 0 10px 20px">
                            <span style="font-weight: 700">{sender}</span>
                            <p>{message_text}</p>
                        </td>
                    </tr>
                    </tbody>
                </table>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                <hr color="#EAE7FF">
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{chat_url}" class="button" style="color: #ffffff">
                    Перейти к сообщению
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 30px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, you have received a new message from a potential buyer <span style='color: #3BD0BC; font-weight: bold'>{sender}</span> on <b>{marketplace_name}</b>!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 20px">
                <hr color="#EAE7FF">
            </td>
        </tr>
        <tr>
            <td>
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%;">
                    <tbody>
                    <tr>
                        <td style="padding: 0 10px 20px">
                            <span style="font-weight: 700">{sender}</span>
                            <p>{message_text}</p>
                        </td>
                    </tr>
                    </tbody>
                </table>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                <hr color="#EAE7FF">
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{chat_url}" class="button" style="color: #ffffff">
                    Go to message
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "new_message_icon.png"

subject_en = "You have ZoneSmart orders to ship today"

title_en = "You have ZoneSmart orders to ship today"

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                As for {current_time} there are some new orders to process, check them out here: https://app.zonesmart.com/admin/warehouse/shipments
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_en = base.cheers_team_email_en



import base64
import importlib
import re
from datetime import datetime
from io import BytesIO

import requests
from django.conf import settings

from zs_utils.api.services import ApiRequestLogService
from zs_utils.exceptions import CustomException
from zs_utils.json_utils import pretty_json


PROJECT_CONST = {
    "default": {
        "MAILGUN_SENDER_DOMAIN": "mg.zonesmart.ru",
        "EMAIL_STATIC_FOLDER_URL": "https://storage.yandexcloud.net/zs-static/email/",
    },
    "oms": {
        "MAILGUN_SENDER_DOMAIN": "mg.zonesmart.ru",
        "EMAIL_STATIC_FOLDER_URL": "https://storage.yandexcloud.net/zs-static/email/",
    },
    "repricer": {
        "MAILGUN_SENDER_DOMAIN": "repricer.zonesmart.su",
        "EMAIL_STATIC_FOLDER_URL": "https://storage.yandexcloud.net/zs-static/email/",
    },
    "landing": {
        "MAILGUN_SENDER_DOMAIN": "landing.zonesmart.su",
        "EMAIL_STATIC_FOLDER_URL": "https://storage.yandexcloud.net/zs-static/email/",
    },
}


class EmailServiceException(CustomException):
    pass


class Unisender:
    API_URL = "https://go1.unisender.ru/ru/transactional/api/v1/"
    FROM_EMAIL = "noreply@id.kokocgroup.ru"

    @classmethod
    def send_email(
            cls,
            receivers: list,
            sender: str,
            subject: str,
            message: str,
            api_key: str,
            files: dict = None,
            message_format: str = "plaintext",
            **kwargs,
    ):
        data = {
            "message": {
                "recipients": [{"email": email} for email in receivers],
                "body": {message_format: message},
                "subject": subject,
                "from_email": cls.FROM_EMAIL,
                "from_name": sender,
                "skip_unsubscribe": 1,
                "attachments": [
                    {"name": name, "content": value, "type": "application/octet-stream"}
                    for name, value in files.items()
                ]
                if files
                else None,
            }
        }

        response = requests.post(
            url=cls.API_URL + "email/send.json", headers={"X-API-KEY": api_key}, json=data,
        )
        ApiRequestLogService.save_api_request_log_by_response(response=response, save_if_is_success=False)
        if not response.ok:
            raise EmailServiceException(pretty_json(response.json()))

        return response.json()

    @classmethod
    def send_html_email(cls, **kwargs):
        return cls.send_email(message_format="html", **kwargs)


class Mailgun:
    API_URL = "https://api.mailgun.net/v3/"

    @staticmethod
    def format_date(date: datetime) -> str:
        """
        Конвертация timezone.datetime в строку формата: '%a, %d %b %Y %H:%M:%S 0000'
        """
        return date.strftime("%a, %d %b %Y %H:%M:%S 0000")

    @classmethod
    def send_email(
            cls,
            project: str,
            sender: str,
            receivers: list,
            subject: str,
            api_key: str,
            text: str = None,
            files: dict = None,
            html: str = None,
            delivery_time: datetime = None,
            tags: list = None,
            **kwargs,
    ) -> dict:
        """
        Отправка email-уведомления на пользовательские email адреса
        """

        attachments = []
        if files:
            for name, base64_file in files.items():
                attachments.append(
                    ("attachment", (name, BytesIO(initial_bytes=base64.b64decode(base64_file.encode()))))
                )

        mailgun_domain = PROJECT_CONST.get(project, PROJECT_CONST["default"])["MAILGUN_SENDER_DOMAIN"]

        data = {
            "from": sender,
            "to": receivers,
            "subject": subject,
            "text": text,
            "html": html,
            "o:tag": tags,
        }
        if delivery_time:
            data["o:deliverytime"] = cls.format_date(delivery_time)
        data = {key: value for key, value in data.items() if value}

        response = requests.post(
            url=f"{cls.API_URL}{mailgun_domain}/messages",
            auth=("api", api_key),
            data=data,
            files=attachments if attachments else None,
        )
        ApiRequestLogService.save_api_request_log_by_response(response=response, save_if_is_success=False)
        return response.json()

    @classmethod
    def send_html_email(cls, message: str, **kwargs):
        return cls.send_email(html=message, **kwargs)


class EmailService(Unisender):
    """
    Сервис для отправки писем по шаблону из mailgun
    """

    # ------------------------------ Генерация полного HTML шаблона ------------------------------
    @classmethod
    def get_template_file(cls, template_name: str):
        """
        Получение файла с частями шаблона
        """
        template_package = getattr(settings, "EMAIL_TEMPLATE_PACKAGE", "zs_utils.email.templates.kokocid")
        if not template_package:
            raise EmailServiceException("Не указан базовый пакет шаблонов в настройках")

        full_template_module = f"{template_package}.{template_name}"

        try:
            template_module = importlib.import_module(full_template_module)
        except ModuleNotFoundError:
            raise EmailServiceException(f"Шаблон {template_name} не найден")

        return template_module

    @classmethod
    def get_template_languages(cls, template_name: str) -> list:
        """
        Получение всех языков шаблона
        """
        template_file = cls.get_template_file(template_name=template_name)
        languages = list()
        for part in dir(template_file):
            if "body" in part:
                languages.append(part.split("_")[-1])
        return languages

    @classmethod
    def get_templates(cls, project: str, base_template: str, template_name: str) -> dict:
        """
        Сбор шаблонов из файла с частями
        """
        templates_dict = dict()
        languages = cls.get_template_languages(template_name=template_name)
        for language in languages:
            template_data = cls.get_template_data(project=project, template_name=template_name, language=language)
            templates_dict[f"{project}.{template_name}.{language}"] = base_template.format(**template_data)
        return templates_dict

    @classmethod
    def validate_template_params(cls, html_template: str, template_params: dict):
        """
        Валидация параметров шаблона
        """
        params = re.findall(pattern=r"{(.*?)}", string=html_template)
        required_params = [template_param.replace("{", "") for template_param in params]

        errors = dict()
        required_params = list(set(required_params))
        for required_param in required_params:
            if required_param not in template_params:
                errors[f"template_params.{required_param}"] = "Обязательное поле."
        if errors:
            raise EmailServiceException(message_dict=errors)

    @classmethod
    def get_template_data(cls, project: str, template_name: str, language: str, template_params: dict) -> dict:
        """
        Получение данных шаблона
        """
        # Базовая информация: файл шаблона с частями и url со статикой
        template_file = cls.get_template_file(template_name=template_name)
        static_url = PROJECT_CONST.get(project, PROJECT_CONST["default"])["EMAIL_STATIC_FOLDER_URL"]
        if not hasattr(template_file, f"body_{language}"):
            raise EmailServiceException(
                message_dict={"language": f"Для данного шаблона не определён язык '{language}'"}
            )

        # Костыль для шаблона zonesmart.order
        if "items" in template_params:
            items = ""
            item_template = getattr(template_file, f"items_{language}", getattr(template_file, "items", None))
            for item in template_params["items"]:
                items += item_template.format(**item)
            template_params["items"] = items

        # Переносим части шаблона в словарь
        title = getattr(template_file, f"title_{language}")
        template_data = {
            "title": title,
            "subject": getattr(template_file, f"subject_{language}", title).format(**template_params),
            "body": getattr(template_file, f"body_{language}"),
            "cheers": getattr(template_file, f"cheers_{language}", ""),
            "footer": getattr(template_file, f"footer_{language}", ""),
            "logo_url": f"{static_url}{template_file.base.logo}",
            "email_icon_url": f"{static_url}{getattr(template_file, 'icon', '')}",
        }

        # Составление полного шаблона из частей
        base_template = template_file.base.base_template
        template_data["html"] = base_template.format(**template_data)
        cls.validate_template_params(html_template=template_data["html"], template_params=template_params)
        template_data["html"] = template_data["html"].format(**template_params)
        return template_data

    # ------------------------------ Отправка email письма ------------------------------

    @classmethod
    def send_template_email(
        cls,
        project: str,
        template_name: str,
        language: str,
        sender: str,
        receivers: list,
        template_params: dict,
        api_key: str,
        files: dict = None,
        **kwargs,
    ):
        """
        Отправка email-уведомления по шаблону
        """
        language = language if language == "ru" else "en"
        template_data = cls.get_template_data(
            project=project, template_name=template_name, language=language, template_params=template_params
        )
        return cls.send_html_email(
            project=project,
            sender=sender,
            receivers=receivers,
            subject=template_data["subject"],
            message=template_data["html"],
            files=files,
            api_key=api_key,
        )



from zs_utils.email.templates.oms import base

icon = "payment_remind_icon.png"

subject_ru = "Привязка банковской карты"

title_ru = "Привязка банковской карты"

body_ru = "Пользователь {name} (email: {email}) привязал карту {card_number}"

cheers_ru = base.cheers_team_email_ru



from zs_utils.email.templates.oms import base

icon = "payment_remind_icon.png"

title_ru = "Пользователь прикрепил платёжное поручение!"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 40px">
                Пользователь {user_id} оплатил счет {payment_number} на сумму {amount} {currency}.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                Подтвердить платеж нужно по ссылке https://app.zonesmart.ru/admin/billing/all в течение двух часов (пн-пт с 10.00-19.00)
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru



from zs_utils.email.templates.oms import base

icon = "token_renewal_icon.png"

title_ru = "Требуется обновление токена аккаунта"
title_en = "Account token update required"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, аккаунт <span style='color: #3BD0BC; font-weight: bold'>{marketplace_user_account}</span> маркетплейса <span style='color: #3BD0BC; font-weight: bold'>{marketplace}</span> был деактивирован из-за устаревшего токена.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                Если у Вас возникли вопросы, ознакомьтесь с <a href='https://zonesmart.zendesk.com/hc/ru/articles/4403027869201' style='color: #3BD0BC; font-weight: bold'>инструкцией по обновлению токена (на примере eBay)</a>, или обратитесь в службу поддержки: <a style="color: #3BD0BC; font-weight: bold">support@zonesmart.ru</a>.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{token_renew_url}" class="button" style="color: #ffffff">
                    Обновить токен
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, account <span style='color: #3BD0BC; font-weight: bold'>{marketplace_user_account}</span> marketplace <span style='color: #3BD0BC; font-weight: bold'>{marketplace}</span> has been deactivated due to a deprecated token.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                For questions, please see <a href='https://zonesmart.zendesk.com/hc/en/articles/4403027869201' style='color: #3BD0BC; font-weight: bold'>instructions for refreshing the token (using eBay as an example)</a>, or contact support: <a style="color: #3BD0BC; font-weight: bold">support@zonesmart.ru</a>.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{token_renew_url}" class="button" style="color: #ffffff">
                    Refresh Token
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "file_sync_fail_icon.png"

title_ru = "Проблема с синхронизацией данных из файла"
title_en = "Problem synchronizing data from the file"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 40px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, сообщаем о возникновении критической ошибки при обработке файла с данными, ранее импортированного в систему.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{source_log_url}" class="button" style="color: #ffffff">
                    Просмотр ошибок
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 40px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, we report a critical error while processing a data file that was previously imported into the system.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{source_log_url}" class="button" style="color: #ffffff">
                    View errors
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "icon_email.png"

title_ru = "Переезд фулфилмента на новый домен"

body_ru = """
<p>Здравствуйте, {first_name}!</p>

<p>Благодарим Вас за использование фулфилмента ZoneSmart. Хотели бы сообщить о важном изменении в работе:</p>

<p><b>С 00:00 часов 13 мая 2024 г. по Московскому времени фулфилмент ZoneSmart будет доступен только по адресу <a href="https://app.zonesmart.com">app.zonesmart.com</a>.</b><br>
Домен app.zonesmart.ru больше с этого момента не будет поддерживаться.</p>

<h3>Что это означает для Вас</h3>
<ol>
<li>Никаких изменений в работе сервиса не произойдет, Вы сможете пользоваться личным кабинетом используя те же учетные данные (email и пароль), что и раньше.</li>
<li>Вся ваша информация (товары, остатки, заказы, интеграции и тд.) на момент 00:00 часов 13 мая 2024 г. будет перенесена на новый домен.</li>
<li>Все заказы, поступившие через домен app.zonesmart.ru до 00:00 часов 13 мая 2024 г. будут обработаны в обычном режиме.</li>
<li>Если вы использовали для оплаты услуг фулфилмента иностранную карту через Stripe, дополнительных действий не требуется. Если же вы использовали карту российского банка, необходимо совершить действие из списка ниже.</li>
</ol>

<h3>Какие действия требуются от Вас</h3>
<ol>
<li>Если вы вносили заказы вручную, то с 00:00 часов 13 мая 2024 г. это нужно будет исключительно через домен <a href="https://app.zonesmart.com">app.zonesmart.com</a>.</li>
<li><b>Если вы использовали для оплаты услуг фулфилмента и доставки карту российского банка — ее необходимо привязать заново на новом домене.</b> Для этого перейдите в раздел <a href="https://app.zonesmart.com/payment"><b>Платежи -> Платежная информация -> Добавить карту</a>.</b><br>
Вся платежная информация с домена app.zonesmart.ru будет удалена.</li>
</ol>

<p>В случае возникновения ошибок при переносе данных или иных проблем просьба обращаться в <a href="https://app.zonesmart.com/support/tickets">службу поддержки в личном кабинете</a>.</p>

<p>С уважением,<br>
Ваша команда ZoneSmart</p>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "icon_email.png"

title_ru = "Изменение email"
title_en = "Email changing"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                Здравствуйте, <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                Для изменения адреса электронной почты вашего аккаунта <span style='color: #3BD0BC; font-weight: bold'>Zonesmart</span>, пожалуйста, нажмите на кнопку ниже.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{reset_email_url}" class="button" style="color: #ffffff">
                    Изменить email
                </a>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                Мы желаем вам удачных продаж по всему миру.
            </td>
        </tr>
        </tbody>
    </table>
"""
body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                Hello, <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                To change your account email address <span style='color: #3BD0BC; font-weight: bold'>Zonesmart</span>, please click the button below.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{reset_email_url}" class="button" style="color: #ffffff">
                    Change email
                </a>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                We wish you successful sales all over the world.
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "payment_remind_icon.png"

title_ru = "Оплата прошла успешно"
title_en = "Payment was successful"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151;box-sizing:border-box;max-width: 420px;width:100%;font-size:13px;line-height:149%;padding:0 20px">
        <tbody>
        <tr>
            <td style="padding:0 0 10px">
                Оплата форвард-отправления №{number} (трек номер консолидации {tracking_number}).
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151;box-sizing:border-box;max-width: 420px;width:100%;font-size:13px;line-height:149%;padding:0 20px">
        <tbody>
        <tr>
            <td style="padding:0 0 10px">
                Payment for forwarding shipment #{number} (consolidation tracking number {tracking_number}).
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "order_icon.png"

title_ru = "Новый заказ"
title_en = "New order"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 40px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, поступил новый заказ {created_date}.
            </td>
        </tr>
        </tbody>
    </table>
    <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 34px">
                <hr color="#EAE7FF">
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px; font-size: 18px">
                Источник: <span style="color: #3BD0BC; font-weight: bold">{channel}</span>
            </td>
        </tr>
        <tr>
            <td style="font-size: 13px">
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%;">
                    <tbody>
                    <tr>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="20%">

                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="45%">
                            Товар
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="15%">
                            Кол-во
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="20%">
                            Цена
                        </td>
                    </tr>
                    {items}
                    </tbody>
                </table>
            </td>
        </tr>
        <tr>
            <td style="padding: 34px 0 34px">
                <hr color="#EAE7FF">
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px; font-size: 18px; font-weight: 700">
                Покупатель:
            </td>
        </tr>
        <tr>
            <td style="font-size: 13px">
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%;">
                    <tbody>
                    <tr>
                        <td>
                            {buyer}
                        </td>
                    </tr>
                    <tr>
                        <td>
                            {phone}
                        </td>
                    </tr>
                    <tr>
                        <td style="padding-bottom: 10px;">
                            {email}
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <b>Адрес:</b> {first_line} {second_line}
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <b>Город:</b> {city}
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <b>Область:</b> {state}
                        </td>
                        <td align="right" style="color: #938C8C">
                            Цена товаров: {currency_code} {subtotal_price}
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <b>Страна:</b> {country}
                        </td>
                        <td align="right" style="color: #938C8C">
                            Доставка: {currency_code} {total_shipping_cost}
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <b>Индекс:</b> {zip_code}
                        </td>
                        <td align="right" style="color: #938C8C">
                            Итог: <span style="color: #3BD0BC; font-weight: bold">{currency_code} {total_price}</span>
                        </td>
                    </tr>
                    </tbody>
                </table>
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 50px 0 40px">
                <a href="{order_url}" class="button" style="color: #ffffff">
                    Перейти к заказу
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 40px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, received a new order {created_date}.
            </td>
        </tr>
        </tbody>
    </table>
    <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 34px">
                <hr color="#EAE7FF">
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px; font-size: 18px">
                Source: <span style="color: #3BD0BC; font-weight: bold">{channel}</span>
            </td>
        </tr>
        <tr>
            <td style="font-size: 13px">
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%;">
                    <tbody>
                    <tr>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="20%">

                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="45%">
                            Product
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="15%">
                            Quantity
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="20%">
                            Price
                        </td>
                    </tr>
                    {items}
                    </tbody>
                </table>
            </td>
        </tr>
        <tr>
            <td style="padding: 34px 0 34px">
                <hr color="#EAE7FF">
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px; font-size: 18px; font-weight: 700">
                Buyer:
            </td>
        </tr>
        <tr>
            <td style="font-size: 13px">
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%;">
                    <tbody>
                    <tr>
                        <td>
                            {buyer}
                        </td>
                    </tr>
                    <tr>
                        <td>
                            {phone}
                        </td>
                    </tr>
                    <tr>
                        <td style="padding-bottom: 10px;">
                            {email}
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <b>Address:</b> {first_line} {second_line}
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <b>City:</b> {city}
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <b>Region:</b> {state}
                        </td>
                        <td align="right" style="color: #938C8C">
                            Products price: {currency_code} {subtotal_price}
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <b>Country:</b> {country}
                        </td>
                        <td align="right" style="color: #938C8C">
                            Delivery: {currency_code} {total_shipping_cost}
                        </td>
                    </tr>
                    <tr>
                        <td>
                            <b>Index:</b> {zip_code}
                        </td>
                        <td align="right" style="color: #938C8C">
                            Total: <span style="color: #3BD0BC; font-weight: bold">{currency_code} {total_price}</span>
                        </td>
                    </tr>
                    </tbody>
                </table>
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 50px 0 40px">
                <a href="{order_url}" class="button" style="color: #ffffff">
                    Go to order
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

items = """
    <tr>
        <td style="padding: 0 10px 10px">
            <img src="{item_img_url}" alt="item_img_url" width="90px">
        </td>
        <td style="padding: 0 10px 10px">
            {title}
            <p style="color: #85868B; font-weight: 400; font-size: 12px; margin: 0; padding-top: 5px">SKU: {sku}</p>
        </td>
        <td style="padding: 0 10px 10px">
            {quantity}
        </td>
        <td style="padding: 0 10px 10px">
            <span style="color: #3BD0BC; font-weight: bold">{currency} {subtotal_price}</span>
        </td>
    </tr>
"""


cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "icon_password.png"

subject_ru = "Сброс пароля"
subject_en = "Password reset"

title_ru = "Забыли Ваш пароль?"
title_en = "Forgot Your password?"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                Похоже, вы хотите сбросить пароль для учетной записи <span style="color: #3BD0BC; font-weight: bold">Zonesmart</span>.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                Не волнуйтесь, вы можете создать новый, нажав кнопку ниже.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 30px">
                <a href="{reset_password_url}" class="button" style="color: #ffffff">
                    Сброс пароля.
                </a>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px; letter-spacing: 0.5px; color: #736E6E; font-size: 12px">
                Если вы не просили нас сбросить пароль, то просто проигнорируйте\nэто письмо. Ваша учетная запись в безопасности.
            </td>
        </tr>
        </tbody>
    </table>
"""
body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                It looks like you want to reset your account password <span style="color: #3BD0BC; font-weight: bold">Zonesmart</span>.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                Don't worry, you can create a new one by clicking the button below.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 30px">
                <a href="{reset_password_url}" class="button" style="color: #ffffff">
                    Password reset.
                </a>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px; letter-spacing: 0.5px; color: #736E6E; font-size: 12px">
                If you didn't ask us to reset your password, please just ignore\nthis email. Your account is safe.
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en

footer_ru = """
    Это письмо было отправлено, потому что вы попросили сбросить пароль на <a href="https://app.zonesmart.com" style="color: #3BD0BC; text-decoration: none">Zonesmart</a>
"""
footer_en = """
    This email was sent because you asked to reset your password on <a href="https://app.zonesmart.com" style="color: #3BD0BC; text-decoration: none">Zonesmart</a>
"""



from zs_utils.email.templates.oms import base

icon = "late_payment_icon.png"

title_ru = "Просрочен платеж"
title_en = "Payment overdue"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, платеж в сумме <span style='color: #3BD0BC; font-weight: bold'>{currency} {amount}</span> не был списан в дату <span style='color: #3BD0BC; font-weight: bold'>{date}</span> из-за ошибки.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                Вы можете обновить метод оплаты, чтобы избежать принудительного перехода на бесплатный тариф.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                Все основные возможности системы, включая обновление остатков и обработку заказов, будут недоступны.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{payment_method_url}" class="button" style="color: #ffffff">
                    Обновить метод оплаты
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, payment in amount <span style='color: #3BD0BC; font-weight: bold'>{currency} {amount}</span> was not debited on date <span style='color: #3BD0BC; font-weight: bold'>{date}</span> due to a bug.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                You can update your payment method to avoid being forced to upgrade to a free plan.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                All the main features of the system, including updating balances and processing orders, will be unavailable.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{payment_method_url}" class="button" style="color: #ffffff">
                    Update payment method
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "payment_remind_icon.png"

title_ru = "Напоминаем Вам о предстоящем платеже"
title_en = "Remind you about the upcoming payment"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, добрый день!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                Напоминаем, что платеж за подписку <span style='color: #3BD0BC; font-weight: bold'>{tariff}</span> в <span style='color: #3BD0BC; font-weight: bold'>{currency} {amount}</span> будет списан через <span style='color: #3BD0BC; font-weight: bold'>{days_before_payment} дня</span> c активной карты.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                Если Вы хотите поменять способ оплаты подписки перейдите по ссылке: <a href="{payment_method_url}" style="color: #3BD0BC; font-weight: bold">{payment_method_url}</a>
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, good afternoon!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                We remind you that the payment for the subscription <span style='color: #3BD0BC; font-weight: bold'>{tariff}</span> in <span style='color: #3BD0BC; font-weight: bold'>{currency} {amount}</span> will be deducted via <span style='color: #3BD0BC; font-weight: bold'>{days_before_payment} of the day</span> from the active card.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                If you want to change the subscription payment method, follow the link: <a href="{payment_method_url}" style="color: #3BD0BC; font-weight: bold">{payment_method_url}</a>
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "icon_email.png"

title_ru = "Напоминание о подтверждении email"
title_en = "Email verification remind"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, добрый день.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                Вы были зарегистрированы в системе <span style='color: #3BD0BC; font-weight: bold'>Zonesmart OMS</span>. Пожалуйста, подтвердите ваш адрес электронной почты <a style='color: #3BD0BC; font-weight: bold'>{email}</a>, чтобы продолжить пользоваться <span style="color: #3BD0BC; font-weight: bold">Zonesmart OMS</span>.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                Для подтверждения адреса электронной почты Вашего аккаунта <span style='color: #3BD0BC; font-weight: bold'>ZoneSmart</span>, пожалуйста, нажмите на кнопку ниже.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0px 0 40px">
                <a href="{accept_email_url}" class="button" style="color: #ffffff">
                    Подтвердить email
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, good afternoon.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                 You were logged in <span style='color: #3BD0BC; font-weight: bold'>Zonesmart OMS</span>. Please verify your email address <a style='color: #3BD0BC; font-weight: bold'>{email}</a> to continue using <span style="color: #3BD0BC; font-weight: bold">Zonesmart OMS</span>.
            </td>
        </tr>
         <tr>
            <td style="padding: 0 0 40px">
                To confirm the email address of your account <span style='color: #3BD0BC; font-weight: bold'>ZoneSmart</span>, please click the button below.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0px 0 40px">
                <a href="{accept_email_url}" class="button" style="color: #ffffff">
                    Confirm email
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "shipment_icon.png"

title_ru = "Создано отправление товаров"
title_en = "Order shipment was created"


body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 40px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, {created_date} было создано отправление товаров.
            </td>
        </tr>
        </tbody>
    </table>
    <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 34px">
                <hr color="#EAE7FF">
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px; font-size: 18px">
                Источник: <span style="color: #3BD0BC; font-weight: bold">{channel}</span>
            </td>
        </tr>
        <tr>
            <td style="font-size: 13px">
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%;">
                    <tbody>
                    <tr>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="20%">

                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="30%">
                            Товар
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="15%">
                            Кол-во
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="20%">
                            Штрих-код
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="15%">
                            Склад
                        </td>
                    </tr>
                    {items}
                    </tbody>
                </table>
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 50px 0 40px">
                <a href="{order_url}" class="button" style="color: #ffffff">
                    Перейти к заказу
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 40px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, {created_date} shipment has been created.
            </td>
        </tr>
        </tbody>
    </table>
    <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 34px">
                <hr color="#EAE7FF">
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px; font-size: 18px">
                Source: <span style="color: #3BD0BC; font-weight: bold">{channel}</span>
            </td>
        </tr>
        <tr>
            <td style="font-size: 13px">
                <table border="0" cellpadding="0" cellspacing="0" width="100%" style="color: #515151; box-sizing:border-box;width:100%; font-size: 13px;line-height: 149%;">
                    <tbody>
                    <tr>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="20%">

                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="30%">
                            Product
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="15%">
                            Quantity
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="20%">
                            Barcode
                        </td>
                        <td style="padding: 0 10px 10px; font-weight: 700" width="15%">
                            Warehouse
                        </td>
                    </tr>
                    {items}
                    </tbody>
                </table>
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 50px 0 40px">
                <a href="{order_url}" class="button" style="color: #ffffff">
                    Go to order
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

items_ru = """
    <tr>
        <td style="padding: 0 10px 10px">
            <img src="{item_img_url}" alt="item_img_url" width="90px">
        </td>
        <td style="padding: 0 10px 10px">
            {title}
            <p style="color: #85868B; font-weight: 400; font-size: 12px; margin: 0; padding-top: 5px">SKU: {sku}</p>
        </td>
        <td style="padding: 0 10px 10px">
            {quantity} шт
        </td>
        <td style="padding: 0 10px 10px">
            {barcode}
        </td>
        <td style="padding: 0 10px 10px">
            {warehouse}
        </td>
    </tr>
"""
items_en = """
    <tr>
        <td style="padding: 0 10px 10px">
            <img src="{item_img_url}" alt="item_img_url" width="90px">
        </td>
        <td style="padding: 0 10px 10px">
            {title}
            <p style="color: #85868B; font-weight: 400; font-size: 12px; margin: 0; padding-top: 5px">SKU: {sku}</p>
        </td>
        <td style="padding: 0 10px 10px">
            {quantity} pcs
        </td>
        <td style="padding: 0 10px 10px">
            {barcode}
        </td>
        <td style="padding: 0 10px 10px">
            {warehouse}
        </td>
    </tr>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "stock_sync_fail_icon.png"

title_ru = "Неудачная синхронизация остатков на канале продаж"
title_en = "Synchronization of stocks on the channel was failed"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, остаток товара не был обновлен на канале продаж <span style='color: #3BD0BC; font-weight: bold'>{channel}</span> из-за возникшей ошибки.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                 Если у Вас возникли вопросы, обратитесь в службу поддержки: <a style="color: #3BD0BC; font-weight: bold">support@zonesmart.ru</a>.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{notification_url}" class="button" style="color: #ffffff">
                    Подробности
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>the rest of the product was not updated on the sales channel <span style='color: #3BD0BC; font-weight: bold'>{channel}</span> due to a bug.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                 If you have any questions, please contact support: <a style="color: #3BD0BC; font-weight: bold">support@zonesmart.ru</a>.
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{notification_url}" class="button" style="color: #ffffff">
                    Details
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "payment_remind_icon.png"

title_ru = "Недостаточно средств для оплаты"
title_en = "Insufficient funds to pay"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                Не удалось обработать заявку на форвардинг №{number} из-за недостатка средств на кошельке.
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                Failed to process request for forwarding #{number} due to lack of funds on the wallet.
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.oms import base

icon = "icon_pricing.png"

title_ru = "Оформление подписки"
title_en = "Subscription created"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, добрый день!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                Вы успешно подключили тарифный план {tariff} ({period_in_days} дней за {currency} {price}) для доступа к системе ZoneSmart. Условия тарифа начнут применяться с {date_active_from}.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                В дальнейшем Вы можете управлять подключенным тарифным планом в настройках вашего профиля
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{tariff_url}" class="button" style="color: #ffffff">
                    Перейти в настройки
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                <span style="color: #3BD0BC; font-weight: bold">{first_name}</span>, good afternoon!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                 You have successfully activated the tariff plan {tariff} ({period_in_days} days for {currency} {price}) to access the ZoneSmart system. Tariff conditions will start to apply from {date_active_from}.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 40px">
                In the future, you can manage the connected tariff plan in your profile settings
            </td>
        </tr>
        <tr>
            <td align="center" style="padding: 0 0 40px">
                <a href="{tariff_url}" class="button" style="color: #ffffff">
                    Go to settings
                </a>
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



logo = "kokocid.png"

base_template = """
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Email-рассылка</title>
</head>
<body style="background-color: #eee;">
    <table align="center" border="0" cellspacing="0" cellpadding="0" role="presentation" style="padding-top: 132px; padding-bottom: 132px;font-family: Arial, Helvetica, sans-serif; font-style: normal; font-weight: 400; font-size: 16px; line-height: 130%;">
        <tr>
            <td>
                <table align="center" border="0" cellspacing="0" cellpadding="0" role="presentation" style="max-width: 600px; width: 100%; background-color: #fff;">
                    <tr style="display: block; background: #fafafa; padding: 29px 32px;">
                        <td>
                            <img src="{logo_url}" alt="">
                        </td>
                    </tr>
                    <tr style="padding-right: 32px;padding-left: 32px;padding-top: 32px; display: block;">
                        <td>
                            <h1 style="font-weight: 700;
                            font-size: 20px;
                            margin-bottom: 12px;
                            margin-top: 0;
                            line-height: 150%;
                            color: #403839;
                            ">{title}</h1>
                        </td>
                    </tr>
                    <tr>
                        <td style="padding-right: 32px; padding-left: 32px; border-radius: 12px; margin-bottom: 16px;">
                            <table align="center" border="0" cellspacing="0" cellpadding="0" role="presentation">
                                {body}
                                <tr>
                                    <td>
                                        <p style="
                                        font-weight: 400;
                                        font-size: 16px;
                                        line-height: 150%;
                                        color: #757070;
                                        margin-top: 0;
                                        margin-bottom: 12px;">
                                            Внимание! <br>
                                            Если вы не запрашивали отправку этого письма, просто проигнорируйте его<br>
                                            С уважением, команда Kokoc ID

                                        </p>
                                    </td>
                                </tr>
                                <tr>
                                    <td>
                                        <h3 style="
                                        margin-top: 0;
                                        margin-bottom: 32px;
                                            font-weight: 400;
                                            font-size: 16px;
                                            line-height: 150%;
                                            color: #aba8a8;
                                        ">Сообщение сгенерировано автоматически.</h3>
                                    </td>
                                </tr>
                            </table>
                        </td>
                    </tr>
                    <tr style="background: #f2f2f2; display: block; display: flex; justify-content: space-between; padding: 35px 32px;
                    font-size: 12px;
                    font-style: normal;
                    font-weight: 400;
                    line-height: 130%; /* 15.6px */
                    letter-spacing: -0.12px;">
                    <td >
                        <a href="/"
                            style="
                            max-width: 130px;
                            font-weight: 400;
                            margin: 0;
                            margin-right: 16px;
                            font-size: 12px;
                            line-height: 150%;
                            text-decoration: underline;
                            text-decoration-skip-ink: none;
                            color: #aba8a8;">
                                Помощь и поддержка
                        </a>

                    </a>
                    </td>
                    <td>
                        <a href="/" style="
                        font-weight: 400;
                        margin: 0;
                        margin-right: 40px;
                        font-size: 12px;
                        line-height: 150%;
                        text-decoration: underline;
                        text-decoration-skip-ink: none;
                        color: #aba8a8;">
                            Политика обработки персональных данных
                    </a>
                    </td>
                    <td>
                        <p style="
                        margin: 0;
                        font-weight: 400;
                        font-size: 12px;
                        line-height: 139%;
                        color: #aba8a8;">2024, © Kokoc Group</p>
                    </td>
                </tr>
                </table>
            </td>
        </tr>
    </table>
</body>
</html>
"""



from zs_utils.email.templates.oms import base

icon = "icon_pricing.png"

title_ru = "Спасибо за регистрацию в ZoneSmart"
title_en = "Thank you for registration in ZoneSmart"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 520px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 15px">
                <span style="color: #3BD0BC; font-weight: bold">{user_first_name}</span>, приветствую Вас!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 15px">
                Меня зовут <span style='color: #3BD0BC; font-weight: bold'>{manager_first_name}</span>, и я менеджер пробного периода в компании <span style='color: #3BD0BC; font-weight: bold'>ZoneSmart</span>, рад знакомству!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 15px">
                Предполагаю, что регистрация в платформе для мульти-канальных продаж - уже не первое Ваше успешное решение за сегодняшний день.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 15px">
                Для того, чтобы в этом убедиться за время бесплатного пробного периода (который, кстати, длится целых 14 дней), я буду рад помогать Вам в процессе освоения нашего сервиса. Периодически я буду присылать рекомендации по работе на почту – они помогут сделать наше взаимодействие эффективнее.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                Перед тем, как Вы <a href='https://zonesmart.zendesk.com/hc/ru/categories/4407691046033' style='color: #3BD0BC; font-weight: bold'>подключите первый аккаунт на маркетплейсе</a> к единому личному кабинету и начнете покорять новые каналы продаж, я бы посоветовал определить сценарий использования сервиса (их может быть <a href='https://zonesmart.zendesk.com/hc/ru/articles/4410033986577' style='color: #3BD0BC; font-weight: bold'>несколько одновременно</a>):
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                1. <a href="https://zonesmart.zendesk.com/hc/ru/articles/4410033986577" style="color: #3BD0BC; font-weight: bold">Интеграция маркетплейса(-ов) с сайтом или системой товароучета.</a>
                <p style="margin: 0px">
                    Позволит массово адаптировать и разместить каталог товаров с сайта на одном или нескольких маркетплейсах. Товарные остатки синхронизируются автоматически, а заказы со всех каналов продаж – выгружаются в Вашу систему.
                </p>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                2. <a href="https://zonesmart.zendesk.com/hc/ru/articles/4410491540113" style="color: #3BD0BC; font-weight: bold">Интеграция аккаунтов на нескольких маркетплейсах между собой.</a>
                <p style="margin: 0px">
                    Подойдет для быстрой синхронизации каталога между маркетплейсами и автономного обновления информации об остатках.
                </p>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                3. <a href="https://zonesmart.zendesk.com/hc/ru/articles/4411155259537" style="color: #3BD0BC; font-weight: bold">Система управления заказами (OMS) для FBS / DBS / RFBS моделей.</a>
                <p style="margin: 0px">
                    Заказы со всех подключенных каналов продаж собираются в одном окне, а встроенные интеграции с популярными курьерскими службами не заставят тратить лишнее время на покупку почтового лейбла на стороннем ресурсе.
                </p>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                4. <a href="https://zonesmart.zendesk.com/hc/ru/articles/4411546464785" style="color: #3BD0BC; font-weight: bold">Система управления клиентской базой (CRM).</a>
                <p style="margin: 0px">
                    Платформа осуществляет сбор данных о покупателях со всех маркетплейсов в едином личном кабинете, упрощая анализ клиентской базы и статистики продаж.
                </p>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 15px">
                В процессе работы, пожалуйста, не забывайте обращаться к нам по любым возникающим вопросам, а также получать удовольствие.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 15px">
                Желаю успехов!
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 520px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 15px">
                <span style="color: #3BD0BC; font-weight: bold">{user_first_name}</span>, greetings!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 15px">
                My name is <span style='color: #3BD0BC; font-weight: bold'>{manager_first_name}</span> and I'm a trial manager at <span style='color: #3BD0BC; font-weight: bold'>ZoneSmart</span>, nice to meet you!
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 15px">
                I assume that registration in the platform for multi-channel sales is not your first successful decision to date.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 15px">
                In order to make sure of this during the free trial period (which, by the way, lasts for 14 days), I will be happy to help you in the process of mastering our service. From time to time I will send recommendations on work by email - they will help make our interaction more efficient.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                Before You <a href='https://zonesmart.zendesk.com/hc/ru/categories/4407691046033' style='color: #3BD0BC; font-weight: bold'>connect the first account on the marketplace</a> to a single personal account and start conquering new sales channels, I would advise you to determine the use case for the service (they can be <a href='https://zonesmart.zendesk .com/hc/en/articles/4410033986577' style='color: #3BD0BC; font-weight: bold'>several at the same time</a>):
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                1. <a href="https://zonesmart.zendesk.com/hc/ru/articles/4410033986577" style="color: #3BD0BC; font-weight: bold">Integration of the marketplace(s) with the website or inventory system.</a>
                <p style="margin: 0px">
                    It will allow you to massively adapt and place a catalog of products from the site on one or more marketplaces. Product stocks are synchronized automatically, and orders from all sales channels are uploaded to your system.
                </p>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                2. <a href="https://zonesmart.zendesk.com/hc/ru/articles/4410491540113" style="color: #3BD0BC; font-weight: bold">Integration of accounts on several marketplaces among themselves.</a>
                <p style="margin: 0px">
                    Suitable for quick synchronization of the catalog between marketplaces and offline updating of information about the stocks.
                </p>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                3. <a href="https://zonesmart.zendesk.com/hc/ru/articles/4411155259537" style="color: #3BD0BC; font-weight: bold">Order Management System (OMS) for FBS / DBS / RFBS models.</a>
                <p style="margin: 0px">
                    Orders from all connected sales channels are collected in one window, and built-in integrations with popular courier services will not make you spend extra time buying a mail label on a third-party resource.
                </p>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 10px">
                4. <a href="https://zonesmart.zendesk.com/hc/ru/articles/4411546464785" style="color: #3BD0BC; font-weight: bold">Customer base management system (CRM).</a>
                <p style="margin: 0px">
                    The platform collects customer data from all marketplaces in a single personal account, simplifying the analysis of the customer base and sales statistics.
                </p>
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 15px">
                In the process of work, please do not forget to contact us for any questions that arise, and also have fun.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 15px">
                I wish you success!
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_manager_email_ru
cheers_en = base.cheers_manager_email_en



from zs_utils.email.templates.oms import base

icon = "payment_remind_icon.png"

subject_ru = "Платеж для аккаунта {email} обработан"
subject_en = "Payment for account {email} processed"

title_ru = "Платеж обработан"
title_en = "Payment processed"

body_ru = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                Спасибо за ваш заказ.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 20px">
                Пожалуйста, проверьте сумму платежа ниже, мы также приложили PDF с подробным описанием вашего заказа и условий подписки.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 5px">
                Аккаунт Zonesmart: {email}
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 5px">
                Метод оплаты: Credit Card
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 5px">
                Дата платежа: {date}
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 20px">
                Сумма: {currency} {amount}
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 30px">
                В случае любых вопросов, пожалуйста, свяжитесь с нами через почту support@zonesmart.ru
            </td>
        </tr>
        </tbody>
    </table>
"""

body_en = """
    <table border="0" cellpadding="0" cellspacing="0" width="100%" align="center" style="color: #515151; box-sizing:border-box;max-width: 420px;width:100%; font-size: 13px;line-height: 149%; padding: 0 20px">
        <tbody>
        <tr>
            <td style="padding: 0 0 10px">
                Thank you for your order.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 20px">
                Please check the payment amount below, we have also attached a PDF detailing your order and subscription terms.
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 5px">
                Zonesmart account: {email}
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 5px">
                Payment method: Credit Card
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 5px">
                Payment date: {date}
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 20px">
                Amount: {currency} {amount}
            </td>
        </tr>
        <tr>
            <td style="padding: 0 0 30px">
                For any questions, please contact us via mail support@zonesmart.ru
            </td>
        </tr>
        </tbody>
    </table>
"""

cheers_ru = base.cheers_team_email_ru
cheers_en = base.cheers_team_email_en



from zs_utils.email.templates.kokocid import base

subject_ru = "Обращение из Kokoc ID"

title_ru = "Kokoc ID: Обращение в поддержку"

body_ru = """
    <tr>
        <td style="padding-right: 32px; padding-left: 32px; border-radius: 12px; margin-bottom: 16px;">
            <table align="left" border="0" cellspacing="0" cellpadding="0" role="presentation">
                <tr>
                    <td>
                        <h2 style="
                        margin: 0;
                        font-weight: 400;
                        font-size: 16px;
                        line-height: 150%;
                        color: #757070;">
                          Email пользователя: {email}
                        </h2>
                        <h2 style="
                        margin: 0;
                        font-weight: 400;
                        font-size: 16px;
                        line-height: 150%;
                        color: #757070;">
                          Телефон пользователя: {phone}
                        </h2>
                        <h2 style="
                        margin: 0;
                        margin-bottom: 24px;
                        font-weight: 400;
                        font-size: 16px;
                        line-height: 150%;
                        color: #757070;">
                          Страница обращения: {page}
                        </h2>
                    </td>
                </tr>
                <tr>
                    <td>
                        <p style="
                        font-weight: 400;
                        font-size: 16px;
                        line-height: 150%;
                        color: #757070;
                        margin-top: 0;
                        margin-bottom: 12px;"
                        >
                          Обращение:<br>
                          {body}
                        </p>
                    </td>
                </tr>
            </table>
        </td>
    </tr>
"""


from zs_utils.email.templates.kokocid import base

subject_ru = "Регистрация в Kokoc ID"

title_ru = "Kokoc ID: Подтверждение регистрации"

body_ru = """
    <tr>
        <td>
            <h2 style="
            margin: 0;
            margin-bottom: 24px;
            font-weight: 400;
            font-size: 16px;
            line-height: 150%;
            color: #757070;">Здравствуйте, Вы получили это сообщение, так как ваш адрес был указан при регистрации в сервисе Kokoc ID.</h2>
        </td>
    </tr>
    <tr>
        <td>
            <p style="
            margin-top: 0;
            margin-bottom: 8px;
            font-weight: 700;
            font-size: 16px;
            line-height: 150%;
            color: #403839;">
                Ваш код подтверждения: </p>
        </td>
    </tr>
    <tr>
        <td>
            <p style="border-bottom: 2px solid #e1e1e1;
            margin-top: 0;
            margin-bottom: 24px;
            background: #f7f7f7;
            font-weight: 700;
            font-size: 24px;
            line-height: 150%;
            color: #f6664b;
                padding: 20px 28px;">
                {code}
            </p>
        </td>
    </tr>
"""